==> glx.ui-1.8.21.tgz: package/components/attestationsList/attestationsList.ts <==
import { Component, EventEmitter, Input, NgModule, OnInit, Output, ViewChild } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';


import { DataTable, DataTableModule } from 'primeng/components/datatable/datatable';
import { DropdownModule } from 'primeng/components/dropdown/dropdown';
import { OverlayPanelModule } from 'primeng/components/overlaypanel/overlaypanel';
import { SharedModule } from 'primeng/components/common/shared';

import { ProfileViewerModule } from '../profileViewer/profileViewer';
import { LoadingBannerModule } from '../loadingBanner/loadingBanner';

import { GlxSharedModule } from '../kernel/shared.module';

/**
 * Фильтр по аттестациям
 */
class Filter {
    faculty: number;
    group: number;
    course: number;
    year: number;
    semester: number;
    discipline: number;
    fullname: string;
    book_num: string;
    num_na: number;
    num_absense: number;
    lecturer: string;
    global: string;

    rows = 20;
    sortField = 'num_na';
    sortOrder = 0;

    constructor() {

    }
}

class Column {
    constructor(public label: string,
                public value: string,
                public selected: boolean) {

    }
}

/**
 * Поиск сотрудников с детальным просмотром профиля
 */
@Component({
    selector: 'glx-attestations-list',
    styleUrls: ['./attestationsList.scss'],
    templateUrl: './attestationsList.html'
})

export class AttestationsList implements OnInit {
    /**
     * Данные для отображения в таблице
     */
    @Input() data: any = {};
    /**
     * Справочники для фильтров
     * @type {{}}
     */
    @Input() catalog: any = {};
    /**
     * Открыт ли фильтр
     * @type {boolean}
     */
    @Input() filterShow: boolean = false;
    /**
     * Показать индикатор загрузки данных
     * @type {boolean}
     */
    @Input() loading: boolean = false;
    /**
     * Задержка поиска для общего фильтра
     * @type {number}
     */
    @Input() filterDelay: number = 1000;
    /**
     * Фильтр
     * @type {Filter}
     */
    @Input() filter: Filter = new Filter();
    /**
     * Надпись на глобальном фильтре
     * @type {string}
     */
    @Input() globalFilterPlaceholder: string = 'Поиск...';
    /**
     * Событие фильтрации. Необходимо получить новые данные сервера
     * @type {EventEmitter<any>}
     */
    @Output() onFilter: EventEmitter<any> = new EventEmitter();
    /**
     * Событий просмотра профиля. Необходимо получить профиль пользователя с сервера
     * @type {EventEmitter<any>}
     */
    @Output() onViewProfile: EventEmitter<any> = new EventEmitter();
    @Output() onViewAttestation: EventEmitter<any> = new EventEmitter();
    @Output() onDownloadExcel: EventEmitter<any> = new EventEmitter();

    /**
     * PrimeNG DataTable
     */
    @ViewChild('dt') datatable: DataTable;
    /**
     * PrimeNg Global Search Field
     */
    @ViewChild('gb') gb: any;
    /**
     * Filter Department Field
     */
    @ViewChild('filterDepartment') filterDepartment: any;
    /**
     * Timeout экземпляр фильтрации
     */
    filterTimeout: any;

    cols: Column[] = [
        {label: 'Подразделение', value: 'faculty', selected: true},
        {label: 'Группа', value: 'group', selected: true},
        {label: 'Курс', value: 'course', selected: true},
        {label: 'Год', value: 'year', selected: true},
        {label: 'Семестр', value: 'semester', selected: true},
        {label: 'Дисциплина', value: 'discipline', selected: true},
        {label: 'ФИО', value: 'fullname', selected: true},
        {label: 'Шифр', value: 'book_num', selected: true},
        {label: 'Неаттестаций', value: 'num_na', selected: true},
        {label: 'Пропусков', value: 'num_absense', selected: true},
        {label: 'Преподаватель', value: 'lecturer', selected: true}
    ];

    selectCol(col) {
        col.selected = !col.selected;
    }

    /**
     * Конструктор
     * @param {Router} router
     * @param {ActivatedRoute} route
     * @param {Renderer2} renderer
     */
    constructor() {
    }

    /**
     * Проверка префильтров
     */
    ngOnInit() {

    }

    /**
     * Очистить фильтр
     */
    clearFilter() {
        this.filter = new Filter();
        if (this.datatable.globalFilter && this.datatable.globalFilter.value) {
            this.datatable.globalFilter.value = '';
        }
        this.datatable.reset();
        this.datatable._filter();
    }

    /**
     * Скрыть / показать фильтры
     */
    toggleFilter() {
        this.filterShow = !this.filterShow;
    }

    /**
     * Применение глобального фильтра
     * @param gbt
     */
    globalFilterApply(gbt) {
        if (this.filterTimeout) {
            clearTimeout(this.filterTimeout);
        }
        if (gbt && gbt.value && gbt.value.length > 2) {
            this.filterTimeout = setTimeout(() => {
                this.datatable.globalFilter = gbt;
                this.datatable._filter();
                this.filterTimeout = null;
            }, this.filterDelay);
        }
        if (gbt && gbt.value === '') {
            this.datatable.globalFilter.value = '';
            this.datatable._filter();
        }
    }

    /**
     * Установка и применение фильтра
     * @param name
     * @param value
     */
    setFilter(name, value) {
        switch (name) {
            case 'fullname':
            case 'book_num':
                if (this.filterTimeout) {
                    clearTimeout(this.filterTimeout);
                }
                if (value && value.length > 2) {
                    this.filterTimeout = setTimeout(() => {
                        this.datatable.filter(value, name, 'any');
                        this.filterTimeout = null;
                    }, this.filterDelay);
                }
                if (value === '') {
                    this.datatable.filter(value, name, 'any');
                }
                break;
            default:
                this.datatable.filter(value, name, 'any');
        }

    }

    /**
     * Устанавилвает фильтр из контекста (при клике на значение в таблице)
     * @param name string Название поля для фильтрации
     * @param value string Значение поля
     */
    setContextFilter($event, name, value) {
        this.filter = new Filter();
        this.datatable.filters = {};
        this.datatable.filteredValue = null;
        this.filter[name] = value;
        this.setFilter(name, value);
        $event.stopPropagation();
    }

    /**
     * Событие для ленивой загрузки. Вызывается при инициализации и фильтрации
     * @param event
     */
    loadItemsLazy(event: any) {
        this.onFilter.emit(event);
    }

    /**
     * Собатие показа профиля в слайдере
     * @param id
     */
    showProfile($event, id) {
        this.onViewProfile.emit(id);
        $event.stopPropagation();
    }


    /**
     * Одиночный щелчок по строке устанавливает ID профиля для возможного открытия
     * @param event
     */
    onRowClick(event) {
        this.onViewAttestation.emit(event.data);
    }

    exportData() {
        this.onDownloadExcel.emit({filter: this.datatable.createLazyLoadMetadata(), cols: this.cols});
    }

    getLecturer(data) {
        return data.split(';').join('<br>');
    }
}

@NgModule({
    imports: [
        CommonModule,
        FormsModule,
        SharedModule,
        GlxSharedModule,
        DataTableModule,
        DropdownModule,
        OverlayPanelModule,
        ProfileViewerModule,
        LoadingBannerModule
    ],
    exports: [AttestationsList],
    declarations: [AttestationsList]
})

export class AttestationsListModule {
}

==> glx.ui-1.8.26.tgz: package/components/attestationsList/attestationsList.ts <==
import { Component, EventEmitter, Input, NgModule, OnInit, Output, ViewChild } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';


import { DataTable, DataTableModule } from 'primeng/components/datatable/datatable';
import { DropdownModule } from 'primeng/components/dropdown/dropdown';
import { OverlayPanelModule } from 'primeng/components/overlaypanel/overlaypanel';
import { SharedModule } from 'primeng/components/common/shared';

import { ProfileViewerModule } from '../profileViewer/profileViewer';
import { LoadingBannerModule } from '../loadingBanner/loadingBanner';

import { GlxSharedModule } from '../kernel/shared.module';

/**
 * Фильтр по аттестациям
 */
class Filter {
    faculty: number;
    group: number;
    course: number;
    year: number;
    semester: number;
    discipline: number;
    fullname: string;
    book_num: string;
    num_na: number;
    num_absense: number;
    lecturer: string;
    global: string;

    filters: any;

    first = 0;
    rows = 20;
    sortField = 'num_na';
    sortOrder = 0;

    constructor() {

    }
}

class Column {
    constructor(public label: string,
                public value: string,
                public selected: boolean) {

    }
}

/**
 * Поиск сотрудников с детальным просмотром профиля
 */
@Component({
    selector: 'glx-attestations-list',
    styleUrls: ['./attestationsList.scss'],
    templateUrl: './attestationsList.html'
})

export class AttestationsList implements OnInit {
    /**
     * Данные для отображения в таблице
     */
    @Input() data: any = {};
    /**
     * Справочники для фильтров
     * @type {{}}
     */
    @Input() catalog: any = {};
    /**
     * Открыт ли фильтр
     * @type {boolean}
     */
    @Input() filterShow: boolean = false;
    /**
     * Показать индикатор загрузки данных
     * @type {boolean}
     */
    @Input() loading: boolean = false;
    /**
     * Задержка поиска для общего фильтра
     * @type {number}
     */
    @Input() filterDelay: number = 1000;
    /**
     * Фильтр
     * @type {Filter}
     */
    @Input() filter: Filter = new Filter();
    /**
     * Надпись на глобальном фильтре
     * @type {string}
     */
    @Input() globalFilterPlaceholder: string = 'Поиск...';
    /**
     * Событие фильтрации. Необходимо получить новые данные сервера
     * @type {EventEmitter<any>}
     */
    @Output() onFilter: EventEmitter<any> = new EventEmitter();
    /**
     * Событий просмотра профиля. Необходимо получить профиль пользователя с сервера
     * @type {EventEmitter<any>}
     */
    @Output() onViewProfile: EventEmitter<any> = new EventEmitter();
    @Output() onViewAttestation: EventEmitter<any> = new EventEmitter();
    @Output() onDownloadExcel: EventEmitter<any> = new EventEmitter();

    /**
     * PrimeNG DataTable
     */
    @ViewChild('dt') datatable: DataTable;
    /**
     * PrimeNg Global Search Field
     */
    @ViewChild('gb') gb: any;
    /**
     * Filter Department Field
     */
    @ViewChild('filterDepartment') filterDepartment: any;
    /**
     * Timeout экземпляр фильтрации
     */
    filterTimeout: any;

    cols: Column[] = [
        {label: 'Подразделение', value: 'faculty', selected: true},
        {label: 'Группа', value: 'group', selected: true},
        {label: 'Курс', value: 'course', selected: true},
        {label: 'Год', value: 'year', selected: true},
        {label: 'Семестр', value: 'semester', selected: true},
        {label: 'Дисциплина', value: 'discipline', selected: true},
        {label: 'ФИО', value: 'fullname', selected: true},
        {label: 'Шифр', value: 'book_num', selected: true},
        {label: 'Неаттестаций', value: 'num_na', selected: true},
        {label: 'Пропусков', value: 'num_absense', selected: true},
        {label: 'Преподаватель', value: 'lecturer', selected: true}
    ];

    selectCol(col) {
        col.selected = !col.selected;
    }

    /**
     * Конструктор
     * @param {Router} router
     * @param {ActivatedRoute} route
     * @param {Renderer2} renderer
     */
    constructor() {
    }

    /**
     * Проверка префильтров
     */
    ngOnInit() {
        this.datatable.filters = this.filter.filters;
    }

    /**
     * Очистить фильтр
     */
    clearFilter() {
        this.filter = new Filter();
        if (this.datatable.globalFilter && this.datatable.globalFilter.value) {
            this.datatable.globalFilter.value = '';
        }
        this.datatable.reset();
        this.datatable._filter();
    }

    /**
     * Скрыть / показать фильтры
     */
    toggleFilter() {
        this.filterShow = !this.filterShow;
    }

    /**
     * Применение глобального фильтра
     * @param gbt
     */
    globalFilterApply(gbt) {
        if (this.filterTimeout) {
            clearTimeout(this.filterTimeout);
        }
        if (gbt && gbt.value && gbt.value.length > 2) {
            this.filterTimeout = setTimeout(() => {
                this.datatable.globalFilter = gbt;
                this.datatable._filter();
                this.filterTimeout = null;
            }, this.filterDelay);
        }
        if (gbt && gbt.value === '') {
            this.datatable.globalFilter.value = '';
            this.datatable._filter();
        }
    }

    /**
     * Установка и применение фильтра
     * @param name
     * @param value
     */
    setFilter(name, value) {
        switch (name) {
            case 'fullname':
            case 'book_num':
                if (this.filterTimeout) {
                    clearTimeout(this.filterTimeout);
                }
                if (value && value.length > 2) {
                    this.filterTimeout = setTimeout(() => {
                        this.datatable.filter(value, name, 'any');
                        this.filterTimeout = null;
                    }, this.filterDelay);
                }
                if (value === '') {
                    this.datatable.filter(value, name, 'any');
                }
                break;
            default:
                this.datatable.filter(value, name, 'any');
        }

    }

    /**
     * Устанавилвает фильтр из контекста (при клике на значение в таблице)
     * @param name string Название поля для фильтрации
     * @param value string Значение поля
     */
    setContextFilter($event, name, value) {
        this.filter = new Filter();
        this.datatable.filters = {};
        this.datatable.filteredValue = null;
        this.filter[name] = value;
        this.setFilter(name, value);
        $event.stopPropagation();
    }

    /**
     * Событие для ленивой загрузки. Вызывается при инициализации и фильтрации
     * @param event
     */
    loadItemsLazy(event: any) {
        this.filter.first = event.first;
        this.filter.rows = event.rows;
        this.filter.sortField = event.sortField;
        this.filter.sortOrder = event.sortOrder;
        this.onFilter.emit(this.filter);
    }

    /**
     * Собатие показа профиля в слайдере
     * @param id
     */
    showProfile($event, id) {
        this.onViewProfile.emit(id);
        $event.stopPropagation();
    }


    /**
     * Одиночный щелчок по строке устанавливает ID профиля для возможного открытия
     * @param event
     */
    onRowClick(event) {
        this.onViewAttestation.emit(event.data);
    }

    exportData() {
        this.onDownloadExcel.emit({filter: this.datatable.createLazyLoadMetadata(), cols: this.cols});
    }

    getLecturer(data) {
        return data.split(';').join('<br>');
    }
}

@NgModule({
    imports: [
        CommonModule,
        FormsModule,
        SharedModule,
        GlxSharedModule,
        DataTableModule,
        DropdownModule,
        OverlayPanelModule,
        ProfileViewerModule,
        LoadingBannerModule
    ],
    exports: [AttestationsList],
    declarations: [AttestationsList]
})

export class AttestationsListModule {
}
